@@ -109,7 +109,8 @@ class account():
         loop = gobject.MainLoop()
         self.control = location.GPSDControl.get_default()
         self.device = location.GPSDevice()
-        self.control.set_properties(preferred_method=location.METHOD_ACWP,
+        #|location.METHOD_AGNSS
+        self.control.set_properties(preferred_method=location.METHOD_ACWP|location.METHOD_GNSS,
                        preferred_interval=location.INTERVAL_DEFAULT)
  
         self.control.connect("error-verbose", self.on_error, loop)
@@ -1525,12 +1526,13 @@ class account():
     def on_changed(self,device, data):
         if self.stopLocation:
             #stoppping location tracking
-            data.stop()
+            #data.stop()
+            print "disabled stop location"
         if not device:
             return
         if device.fix:
             if device.fix[1] & location.GPS_DEVICE_LATLONG_SET:
-                print "lat = %f, long = %f" % device.fix[4:6]
+                #print "lat = %f, long = %f" % device.fix[4:6]
                 self.lat, self.long = device.fix[4:6]
                 #data.stop()
     
