@@ -278,6 +278,8 @@ class Witter():
             print "Tweet Failed"
             hildon.hildon_banner_show_information(self.ui.window, "", "Tweet Failed")
         self.ui.showBusy(-1)
+        profileUpdateThread = witter.RefreshTask(self.setProfile, 0, None)
+        profileUpdateThread.refresh()
 
 
     def FollowTweetAuthor(self, widget):
@@ -778,9 +780,12 @@ class Witter():
     def configOauth(self, widget, account, *args):
          try:
              twitter = oauthtwitter.OAuthApi(self.CONSUMER_KEY, self.CONSUMER_SECRET)
+             
              self.request_token = twitter.getRequestToken()
+             print "obtained oauth request_token"
+             print "requesting auth url"
              authorization_url = twitter.getAuthorizationURL(self.request_token)
-             print authorization_url
+             print "authorization url is " + authorization_url
              self.osso_rpc.rpc_run_with_defaults("osso_browser", "open_new_window", (authorization_url,))
              self.auth_account = account
              #ask the ui to prompt user to go to browser etc.
@@ -996,7 +1001,7 @@ class Witter():
         self.establish_connection()
         self.activeAcount.FollowUser(widget, self.reply_to_name)
         self.ui.showBusy(-1)
-
+  
 
     def getTrendsWrapper(self, get_older=False, autoval=None, more=0, *args):
         self.ui.showBusy(1)
